==> hollow-cli-1.3.9.tgz: package/esm/buildCore.js <==
/**************************************************
 * Created by nanyuantingfeng on 23/08/2017 17:29.
 **************************************************/
import path from 'path';
import { webpack } from './plugins';
import { notifier } from './util';
import PromiseDefer from './PromiseDefer';
process.on('unhandledRejection', function (err) {
  throw err;
});
export default function (context) {
  var webpackConfig = context.webpackConfig;
  webpackConfig = Array.isArray(webpackConfig) ? webpackConfig : [webpackConfig];
  var fileOutputPath;
  webpackConfig.forEach(function (config) {
    fileOutputPath = config.output.path;
  });
  var defer = PromiseDefer();

  function compileDoneHandler(err, stats) {
    if (err) {
      console.error(err);
      defer.reject(err);
      process.on('exit', function () {
        process.exit(1);
      });
    }

    if (!stats) {
      defer.resolve();
      return;
    }

    try {
      var _stats$toJson = stats.toJson(),
          errors = _stats$toJson.errors;

      if (errors && errors.length) {
        process.on('exit', function () {
          process.exit(1);
        });
      }
    } catch (e) {
      console.error(e);
      process.on('exit', function () {
        process.exit(1);
      });
    }

    if (!context.watch || stats.hasErrors()) {
      var buildInfo = stats.toString({
        colors: true,
        children: true,
        chunks: !!context.verbose,
        modules: !!context.verbose,
        chunkModules: !!context.verbose,
        hash: !!context.verbose,
        version: !!context.verbose
      });

      if (stats.hasErrors()) {
        console.error(buildInfo);
      } else {
        console.log(buildInfo);
        notifier.notify({
          title: 'HOLLOW CLI',
          message: 'DONE',
          subtitle: 'build successfully',
          contentImage: path.join(__dirname, '../assets/success.png'),
          sound: 'Glass'
        });
      }
    }

    defer.resolve();
  }

  var compiler = webpack(webpackConfig);

  if (!context.verbose) {
    compiler.hooks.done.tap('mini-css-extract-plugin', function (stats) {
      stats.stats.forEach(function (stat) {
        stat.compilation.children = stat.compilation.children.filter(function (child) {
          return !child.name.startsWith('mini-css-extract-plugin');
        });
      });
    });
  }

  if (context.watch) {
    compiler.watch(context.watch || 200, compileDoneHandler);
  } else {
    compiler.run(compileDoneHandler);
  }

  return defer.promise;
}

==> hollow-cli-1.3.14.tgz: package/esm/buildCore.js <==
/**************************************************
 * Created by nanyuantingfeng on 23/08/2017 17:29.
 **************************************************/
import path from 'path';
import { webpack } from './plugins';
import { notifier } from './util';
import PromiseDefer from './PromiseDefer';
import getStats from './getStats';
process.on('unhandledRejection', function (err) {
  throw err;
});
export default function (context) {
  var webpackConfig = context.webpackConfig;
  webpackConfig = Array.isArray(webpackConfig) ? webpackConfig : [webpackConfig];
  var fileOutputPath;
  webpackConfig.forEach(function (config) {
    fileOutputPath = config.output.path;
  });
  var defer = PromiseDefer();

  function compileDoneHandler(err, stats) {
    if (err) {
      console.error(err);
      defer.reject(err);
      process.on('exit', function () {
        process.exit(1);
      });
    }

    if (!stats) {
      defer.resolve();
      return;
    }

    try {
      var _stats$toJson = stats.toJson(),
          errors = _stats$toJson.errors;

      if (errors && errors.length) {
        process.on('exit', function () {
          process.exit(1);
        });
      }
    } catch (e) {
      console.error(e);
      process.on('exit', function () {
        process.exit(1);
      });
    }

    if (!context.watch || stats.hasErrors()) {
      var buildInfo = stats.toString(getStats(context.verbose));

      if (stats.hasErrors()) {
        console.error(buildInfo);
      } else {
        console.log(buildInfo);
        notifier.notify({
          title: 'HOLLOW CLI',
          message: 'DONE',
          subtitle: 'build successfully',
          contentImage: path.join(__dirname, '../assets/success.png'),
          sound: 'Glass'
        });
      }
    }

    defer.resolve();
  }

  var compiler = webpack(webpackConfig);

  if (!context.verbose) {
    compiler.hooks.done.tap('mini-css-extract-plugin', function (stats) {
      stats.stats.forEach(function (stat) {
        stat.compilation.children = stat.compilation.children.filter(function (child) {
          return !child.name.startsWith('mini-css-extract-plugin');
        });
      });
    });
  }

  if (context.watch) {
    compiler.watch(context.watch || 200, compileDoneHandler);
  } else {
    compiler.run(compileDoneHandler);
  }

  return defer.promise;
}
